@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <gtkmm/table.h>
 #include <gtkmm/box.h>
 #include <gtkmm/tooltips.h>
+#include <gtkmm/optionmenu.h>
 
 namespace GParted
 {
@@ -41,7 +42,7 @@ public:
 	~Dialog_Base_Partition( ) ;
 
 	void Set_Resizer( bool extended ) ;
-	Partition Get_New_Partition( ) ;
+	Partition Get_New_Partition( Byte_Value sector_size ) ;
 	
 protected:
 	enum SPINBUTTON {
@@ -69,11 +70,17 @@ protected:
 
 	Gtk::HBox hbox_main ;
 	Gtk::SpinButton spinbutton_before, spinbutton_size, spinbutton_after;
-	Gtk::CheckButton checkbutton_round_to_cylinders ;
+	Gtk::OptionMenu optionmenu_alignment ;
+	Gtk::Menu menu_alignment ;
 
 	//used to enable/disable OKbutton...
 	int ORIG_BEFORE, ORIG_SIZE, ORIG_AFTER ;
-	
+
+	//used to reserve space for Master or Extended Boot Record (1 MiB)
+	int MIN_SPACE_BEFORE_MB ;
+
+	int MB_Needed_for_Boot_Record( const Partition & partition ) ;
+
 	//signal handlers
 	void on_signal_move( int, int );
 	void on_signal_resize( int, int, Frame_Resizer_Base::ArrowType );
