@@ -1,4 +1,4 @@
-/* Copyright (C) 2008 Curtis Gedak
+/* Copyright (C) 2008, 2009 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,13 +27,19 @@ class FS_Info
 {
 public:
 	FS_Info() ;
+	FS_Info( bool do_refresh ) ;
 	~FS_Info() ;
+	Glib::ustring get_fs_type( const Glib::ustring & path ) ;
 	Glib::ustring get_label( const Glib::ustring & path, bool & found ) ;
 	Glib::ustring get_uuid( const Glib::ustring & path ) ;
 private:
 	void load_fs_info_cache() ;
+	void set_commands_found() ;
 	Glib::ustring get_device_entry( const Glib::ustring & path ) ;
-	Glib::ustring fs_info_cache ;
+	static bool fs_info_cache_initialized ;
+	static bool blkid_found ;
+	static bool vol_id_found ;
+	static Glib::ustring fs_info_cache ;
 };
 
 }//GParted
