@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,6 +44,13 @@ enum PartitionStatus {
 	STAT_FORMATTED	=	3
 };
 
+enum PartitionAlignment {
+	ALIGN_CYLINDER = 0,    //Align to nearest cylinder
+	ALIGN_MEBIBYTE = 1,    //Align to nearest mebibyte
+	ALIGN_STRICT   = 2     //Strict alignment - no rounding
+	                       //  Indicator if start and end sectors must remain unchanged
+};
+
 //FIXME: we should make a difference between partition- and file system size. 
 //especially in the core this can make a difference when giving detailed feedback. With new cairosupport in gtkmm
 //it's even possible to make stuff like this visible in the GUI in a nice and clear way
@@ -64,6 +71,7 @@ public:
 			FILESYSTEM filesystem,
 			Sector sector_start,
 			Sector sector_end,
+			Byte_Value sector_size,
 			bool inside_extended,
 			bool busy ) ;
 
@@ -73,6 +81,7 @@ public:
 	void Set_Unallocated( const Glib::ustring & device_path, 
 			      Sector sector_start,
 			      Sector sector_end,
+			      Byte_Value sector_size,
 			      bool inside_extended );
 
 	//update partition number (used when a logical partition is deleted) 
@@ -80,7 +89,8 @@ public:
 	
 	void add_path( const Glib::ustring & path, bool clear_paths = false ) ;
 	void add_paths( const std::vector<Glib::ustring> & paths, bool clear_paths = false ) ;
-	Sector get_length() const ; 
+	Byte_Value get_byte_length() const ;
+	Sector get_sector_length() const ; 
 	Glib::ustring get_path() const ;
 	std::vector<Glib::ustring> get_paths() const ;
 	void add_mountpoints( const std::vector<Glib::ustring> & mountpoints, bool clear_mountpoints = false ) ;
@@ -98,6 +108,7 @@ public:
 	int partition_number;
 	PartitionType type;// UNALLOCATED, PRIMARY, LOGICAL, etc...
 	PartitionStatus status; //STAT_REAL, STAT_NEW, etc..
+	PartitionAlignment alignment;   //ALIGN_CYLINDER, ALIGN_STRICT, etc
 	FILESYSTEM filesystem ;
 	Glib::ustring label ;
 	Glib::ustring uuid ;
@@ -113,9 +124,11 @@ public:
 	
 	std::vector<Partition> logicals ;
 
-	bool strict ;		//Indicator if start and end sectors must stay unchanged
 	bool strict_start ;	//Indicator if start sector must stay unchanged
-	
+	Sector free_space_before ;  //Free space preceding partition value
+
+	Byte_Value sector_size ;  //Sector size of the disk device needed for converting to/from sectors and bytes.
+
 private:
 	void sort_paths_and_remove_duplicates() ;
 
