@@ -38,12 +38,13 @@ namespace GParted
 {
 
 typedef long long Sector;
+typedef long long Byte_Value;
 
-//sizeunits defined in sectors of 512 bytes..
-#define KIBIBYTE 2
-#define MEBIBYTE 2048  
-#define GIBIBYTE 2097152
-#define TEBIBYTE 2147483648U 
+//Size units defined in bytes
+const Byte_Value KIBIBYTE=1024;
+const Byte_Value MEBIBYTE=(KIBIBYTE * KIBIBYTE);
+const Byte_Value GIBIBYTE=(MEBIBYTE * KIBIBYTE);
+const Byte_Value TEBIBYTE=(GIBIBYTE * KIBIBYTE);
 
 enum FILESYSTEM
 {
@@ -108,8 +109,8 @@ struct FS
 	Support check ; //some checktool available?
 	Support copy ;
 
-	Sector MIN ; 
-	Sector MAX ;
+	Byte_Value MIN ; 
+	Byte_Value MAX ;
 	
 	FS()
 	{
@@ -135,9 +136,9 @@ public:
 	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf( FILESYSTEM filesystem, int width, int height ) ;
 	static Glib::ustring get_filesystem_string( FILESYSTEM filesystem ) ;
 	static Glib::ustring get_filesystem_software( FILESYSTEM filesystem ) ;
-	static Glib::ustring format_size( Sector size ) ;
+	static Glib::ustring format_size( Sector sectors, Byte_Value sector_size ) ;
 	static Glib::ustring format_time( std::time_t seconds ) ;
-	static double sector_to_unit( Sector sectors, SIZE_UNIT size_unit ) ;
+	static double sector_to_unit( Sector sectors, Byte_Value sector_size, SIZE_UNIT size_unit ) ;
 	static int execute_command( const Glib::ustring & command ) ;
 	static int execute_command( const Glib::ustring & command,
 				    Glib::ustring & output,
