@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -168,6 +168,8 @@ private:
 	
 	void activate_undo();
 	void remove_operation( int index = -1, bool remove_all = false ) ;
+	int  partition_in_operation_queue_count( const Partition & partition ) ;
+	int  active_partitions_on_device_count( const Device & device ) ;
 	void activate_apply();
 
 //private variables
