@@ -66,19 +66,25 @@ DialogFeatures::DialogFeatures()
 	hbox = manage( new Gtk::HBox() ) ;
 	image = manage( new Gtk::Image( Gtk::Stock::APPLY, Gtk::ICON_SIZE_LARGE_TOOLBAR ) );
 	hbox ->pack_start( *image, Gtk::PACK_SHRINK ) ;
-	hbox ->pack_start( * Utils::mk_label( _("Available") ), Gtk::PACK_EXPAND_WIDGET ) ;
+	hbox ->pack_start( * Utils::mk_label(
+			/* TO TRANSLATORS:  Available
+			 * means that this action is valid for this file system.
+			 */
+			_("Available") ), Gtk::PACK_EXPAND_WIDGET ) ;
 	vbox ->pack_start( *hbox ) ;
 
 	hbox = manage( new Gtk::HBox() ) ;
 	image = manage( new Gtk::Image( Gtk::Stock::CANCEL, Gtk::ICON_SIZE_LARGE_TOOLBAR ) );
 	hbox ->pack_start( *image, Gtk::PACK_SHRINK ) ;
-	hbox ->pack_start( * Utils::mk_label( _("Not Available") ), Gtk::PACK_EXPAND_WIDGET ) ;
+	hbox ->pack_start( * Utils::mk_label(
+			/* TO TRANSLATORS:  Not Available
+			 * means that this action is not valid for this file system.
+			 */
+			_("Not Available") ), Gtk::PACK_EXPAND_WIDGET ) ;
 	vbox ->pack_start( *hbox ) ;
 	hbox2 ->pack_start( *vbox ) ;
 
 	//legend
-	hbox = manage( new Gtk::HBox( false, 6 ) ) ;
-	hbox ->set_border_width( 6 ) ;
 	str_temp = "<b>" ;
 	str_temp += _("Legend") ;
 	str_temp += "</b>" ;
@@ -105,8 +111,8 @@ void DialogFeatures::load_filesystems( const std::vector<FS> & FILESYSTEMS )
 	//fill the features chart with valid file systems 
 	for ( unsigned short t = 0; t < FILESYSTEMS .size() ; t++ )
 	{
-		//Skip btrfs, luks, lvm2, and unknown because these are not file systems
-		if ( FILESYSTEMS[ t ] .filesystem == GParted::FS_BTRFS ||
+		//Skip luks, lvm2, and unknown because these are not file systems
+		if (
 		     FILESYSTEMS[ t ] .filesystem == GParted::FS_LUKS ||
 		     FILESYSTEMS[ t ] .filesystem == GParted::FS_LVM2 ||
 		     FILESYSTEMS[ t ] .filesystem == GParted::FS_UNKNOWN
