@@ -171,10 +171,20 @@ Partition Dialog_Base_Partition::Get_New_Partition( Byte_Value sector_size )
 	switch ( optionmenu_alignment .get_history() )
 	{
 		case  0 :  selected_partition .alignment = ALIGN_CYLINDER;  break;
-		case  1 :  selected_partition .alignment = ALIGN_MEBIBYTE;  break;
+		case  1 :  selected_partition .alignment = ALIGN_MEBIBYTE;
+		           {
+		               //if start sector not MiB aligned and free space available then add ~1 MiB to partition so requested size is kept
+		               Sector diff = ( MEBIBYTE / selected_partition .sector_size ) - ( selected_partition .sector_end + 1 ) % ( MEBIBYTE / selected_partition .sector_size ) ;
+		               if (   diff
+		                   && ( selected_partition .sector_start % (MEBIBYTE / selected_partition .sector_size ) ) > 0
+		                   && ( ( selected_partition .sector_end - START +1 + diff ) < total_length )
+		                  )
+		                   selected_partition .sector_end += diff ;
+		           }
+		           break;
 		case  2 :  selected_partition .alignment = ALIGN_STRICT;  break;
 
-		default :  selected_partition .alignment = ALIGN_CYLINDER ;
+		default :  selected_partition .alignment = ALIGN_MEBIBYTE ;
 	}
 
 	selected_partition .free_space_before = Sector(spinbutton_before .get_value_as_int()) * (MEBIBYTE / sector_size) ;
@@ -241,8 +251,8 @@ void Dialog_Base_Partition::on_signal_move( int x_start, int x_end )
 {  
 	GRIP = true ;
 
-	spinbutton_before .set_value( x_start <= MIN_SPACE_BEFORE_MB * MB_PER_PIXEL ? MIN_SPACE_BEFORE_MB : x_start * MB_PER_PIXEL ) ;
-	
+	spinbutton_before .set_value( x_start * MB_PER_PIXEL ) ;
+
 	if ( x_end == 500 )
 	{
 		spinbutton_after .set_value( 0 ) ;
@@ -275,17 +285,8 @@ void Dialog_Base_Partition::on_signal_resize( int x_start, int x_end, Frame_Resi
 			spinbutton_after .set_value( TOTAL_MB - before_value - spinbutton_size .get_value() ) ;
 	}
 	else if ( arrow == Frame_Resizer_Base::ARROW_LEFT ) //don't touch freespace after, leave it as it is
-	{
-		if ( x_start <= MIN_SPACE_BEFORE_MB * MB_PER_PIXEL )
-		{
-			spinbutton_before .set_value( MIN_SPACE_BEFORE_MB );
-			spinbutton_size .set_value( TOTAL_MB - MIN_SPACE_BEFORE_MB - spinbutton_after.get_value() ) ;
-		}
-		else
-			spinbutton_before .set_value(
-				TOTAL_MB - spinbutton_size .get_value() - spinbutton_after .get_value() ) ;
-	}
-		
+		spinbutton_before .set_value( TOTAL_MB - spinbutton_size .get_value() - spinbutton_after .get_value() ) ;
+
 	Check_Change() ;
 	
 	GRIP = false ;
@@ -344,8 +345,7 @@ void Dialog_Base_Partition::Check_Change()
 
 Dialog_Base_Partition::~Dialog_Base_Partition() 
 {
-	if ( frame_resizer_base )
-		delete frame_resizer_base ;
+	delete frame_resizer_base;
 }
 
 } //GParted
