@@ -58,17 +58,17 @@ void Dialog_Partition_New::Set_Data( const Partition & partition,
 			this ->FILESYSTEMS .erase( this->FILESYSTEMS .begin() + t ) ;
 	}
 
-	FS *fs_tmp ;
+	FS fs_tmp ;
 	//add FS_UNFORMATTED
-	fs_tmp = new( FS ) ;
-	fs_tmp ->filesystem = GParted::FS_UNFORMATTED ;
-	fs_tmp ->create = GParted::FS::LIBPARTED ;
-	this ->FILESYSTEMS .push_back( * fs_tmp ) ;
+	fs_tmp .filesystem = GParted::FS_UNFORMATTED ;
+	fs_tmp .create = GParted::FS::LIBPARTED ;
+	this ->FILESYSTEMS .push_back( fs_tmp ) ;
 
 	//add FS_EXTENDED
-	fs_tmp = new( FS ) ;
-	fs_tmp ->filesystem = GParted::FS_EXTENDED ;
-	this ->FILESYSTEMS .push_back( * fs_tmp ) ;
+	fs_tmp = FS();
+	fs_tmp .filesystem = GParted::FS_EXTENDED ;
+	fs_tmp .create = GParted::FS::NONE ;
+	this ->FILESYSTEMS .push_back( fs_tmp ) ;
 	
 	//add table with selection menu's...
 	table_create .set_border_width( 10 ) ;
@@ -227,7 +227,17 @@ Partition Dialog_Partition_New::Get_New_Partition( Byte_Value sector_size )
 	switch ( optionmenu_alignment .get_history() )
 	{
 		case  0 :  part_temp .alignment = GParted::ALIGN_CYLINDER;  break;
-		case  1 :  part_temp .alignment = GParted::ALIGN_MEBIBYTE;  break;
+		case  1 :  part_temp .alignment = GParted::ALIGN_MEBIBYTE;
+		           {
+		               //if start sector not MiB aligned and free space available then add ~1 MiB to partition so requested size is kept
+		               Sector diff = ( MEBIBYTE / part_temp .sector_size ) - ( part_temp .sector_end + 1 ) % ( MEBIBYTE / part_temp .sector_size ) ;
+		               if (   diff
+		                   && ( part_temp .sector_start % (MEBIBYTE / part_temp .sector_size ) ) > 0
+		                   && ( ( part_temp .sector_end - START +1 + diff ) < total_length )
+		                  )
+		                   part_temp .sector_end += diff ;
+		           }
+		           break;
 		case  2 :  part_temp .alignment = GParted::ALIGN_STRICT;  break;
 
 		default :  part_temp .alignment = GParted::ALIGN_MEBIBYTE ;
@@ -310,6 +320,7 @@ void Dialog_Partition_New::optionmenu_changed( bool type )
 
 void Dialog_Partition_New::Build_Filesystems_Menu( bool only_unformatted ) 
 {
+	bool set_first=false;
 	//fill the file system menu with the file systems (except for extended) 
 	for ( unsigned int t = 0 ; t < FILESYSTEMS .size( ) ; t++ ) 
 	{
@@ -321,18 +332,28 @@ void Dialog_Partition_New::Build_Filesystems_Menu( bool only_unformatted )
 		menu_filesystem .items() .back() .set_sensitive(
 			! only_unformatted && FILESYSTEMS[ t ] .create &&
 			this ->selected_partition .get_byte_length() >= FILESYSTEMS[ t ] .MIN ) ;
+		//use ext2 as default filesystem
+		if ( Utils::get_filesystem_string( FILESYSTEMS[ t ] .filesystem ) == "ext2" &&
+			menu_filesystem .items() .back() .sensitive() )
+		{
+			first_creatable_fs=menu_filesystem .items() .size() - 1;
+			set_first=true;
+		}
 	}
 	
 	//unformatted is always available
 	menu_filesystem .items() .back() .set_sensitive( true ) ;
 	
-	//find and set first enabled file system
-	for ( unsigned int t = 0 ; t < menu_filesystem .items() .size() ; t++ )
-		if ( menu_filesystem .items()[ t ] .sensitive() )
-		{
-			first_creatable_fs = t ;
-			break ;
-		}
+	if(!set_first)
+	{
+		//find and set first enabled file system
+		for ( unsigned int t = 0 ; t < menu_filesystem .items() .size() ; t++ )
+			if ( menu_filesystem .items()[ t ] .sensitive() )
+			{
+				first_creatable_fs = t ;
+				break ;
+			}
+	}
 }
 
 } //GParted
