@@ -23,22 +23,19 @@ namespace GParted
 	
 FileSystem::FileSystem()
 {
-	cylinder_size = 0 ;
 }
 
-int FileSystem::execute_command( const Glib::ustring & command, std::vector<OperationDetails> & operation_details ) 
+int FileSystem::execute_command( const Glib::ustring & command, OperationDetail & operationdetail ) 
 {
-	operation_details .push_back( OperationDetails( "<b><i>" + command + "</i></b>", OperationDetails::NONE ) ) ;
+	operationdetail .add_child( OperationDetail( command, STATUS_NONE, FONT_BOLD_ITALIC ) ) ;
 
-	int exit_status = Utils::execute_command( command, output, error ) ;
+	int exit_status = Utils::execute_command( "nice -n 19 " + command, output, error ) ;
 
 	if ( ! output .empty() )
-		operation_details .back() .sub_details .push_back(
-				OperationDetails( "<i>" + output + "</i>", OperationDetails::NONE ) ) ;
+		operationdetail .get_last_child() .add_child( OperationDetail( output, STATUS_NONE, FONT_ITALIC ) ) ;
 	
 	if ( ! error .empty() )
-		operation_details .back() .sub_details .push_back( 
-				OperationDetails( "<i>" + error + "</i>", OperationDetails::NONE ) ) ;
+		operationdetail .get_last_child() .add_child( OperationDetail( error, STATUS_NONE, FONT_ITALIC ) ) ;
 
 	return exit_status ;
 }
