@@ -33,6 +33,7 @@
 #include "../include/OperationFormat.h"
 #include "../include/OperationResizeMove.h"
 #include "../include/OperationLabelPartition.h"
+#include "../config.h"
 
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/messagedialog.h>
@@ -392,8 +393,8 @@ Gtk::Menu * Win_GParted::create_format_menu()
 
 	for ( unsigned int t =0; t < gparted_core .get_filesystems() .size() ; t++ )
 	{
-		//Skip btrfs, luks, lvm2, and unknown because these are not file systems
-		if ( gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_BTRFS ||
+		//Skip luks, lvm2, and unknown because these are not file systems
+		if (
 		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LUKS ||
 		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_LVM2 ||
 		     gparted_core .get_filesystems()[ t ] .filesystem == GParted::FS_UNKNOWN
@@ -1264,7 +1265,7 @@ void Win_GParted::menu_help_contents()
 	tmp_msg += "\n" ;
 	tmp_msg += _( "Documentation is available at the project web site." ) ;
 	tmp_msg += "\n" ;
-	tmp_msg += "http://gparted.sourceforge.net" ;
+	tmp_msg += "http://gparted.org" ;
 	dialog .set_secondary_text( tmp_msg ) ;
 	dialog .run() ;
 #else
@@ -1293,7 +1294,7 @@ void Win_GParted::menu_help_about()
 	strings .clear() ;
 
 	//artists
-	strings .push_back( "http://gparted.sourceforge.net/artwork.php" ) ;
+	strings .push_back( "http://gparted.org/artwork.php" ) ;
 	dialog .set_artists( strings ) ;
 	strings .clear() ;
 
@@ -1305,7 +1306,7 @@ void Win_GParted::menu_help_about()
 
 
   	//the url is not clickable because this would introduce an new dep (gnome-vfsmm) 
-	dialog .set_website( "http://gparted.sourceforge.net" ) ;
+	dialog .set_website( "http://gparted.org" ) ;
 
 	dialog .run() ;
 }
@@ -1341,8 +1342,12 @@ bool Win_GParted::max_amount_prim_reached()
 	{
 		Gtk::MessageDialog dialog( 
 			*this,
-			String::ucompose( _("It is not possible to create more than %1 primary partitions"),
-					  devices[ current_device ] .max_prims ),
+			String::ucompose( ngettext( "It is not possible to create more than %1 primary partition"
+			                          , "It is not possible to create more than %1 primary partitions"
+			                          , devices[ current_device ] .max_prims
+			                          )
+			                , devices[ current_device ] .max_prims
+			                ),
 			false,
 			Gtk::MESSAGE_ERROR,
 			Gtk::BUTTONS_OK,
@@ -1424,6 +1429,33 @@ void Win_GParted::activate_resize()
 			operation ->icon = render_icon( Gtk::Stock::GOTO_LAST, Gtk::ICON_SIZE_MENU );
 
 			Add_Operation( operation ) ;
+
+			//Display notification if move operation has been queued
+			if ( operation ->partition_original .sector_start != operation ->partition_new .sector_start )
+			{
+				//Warn that move operation might break boot process
+				Gtk::MessageDialog dialog( *this
+				                         , _( "Moving a partition might cause your operating system to fail to boot." )
+				                         , false
+				                         , Gtk::MESSAGE_WARNING
+				                         , Gtk::BUTTONS_OK
+				                         , true
+				                         ) ;
+				Glib::ustring tmp_msg =
+					/*TO TRANSLATORS: looks like   You queued an operation to move the start sector of partition /dev/sda3. */
+					String::ucompose( _( "You have queued an operation to move the start sector of partition %1." )
+					                , operation ->partition_original .get_path()
+					                ) ;
+				tmp_msg += "  Failure to boot is most likely to occur if you move the GNU/Linux partition containing /boot, or if you move the Windows system partition C:." ;
+				tmp_msg += "\n" ;
+				tmp_msg += _( "You can learn how to repair the boot configuration in the GParted FAQ." ) ;
+				tmp_msg += "\n" ;
+				tmp_msg += "http://gparted.org/faq.php" ;
+				tmp_msg += "\n\n" ;
+				tmp_msg += "Moving a partition might take a very long time to apply." ;
+				dialog .set_secondary_text( tmp_msg ) ;
+				dialog .run() ;
+			}
 		}
 	}
 }
@@ -1643,20 +1675,30 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 	     ( fs .MAX && selected_partition .get_byte_length() > fs .MAX ) )
 	{
 		Gtk::MessageDialog dialog( *this,
-					   String::ucompose( _("Cannot format this file system to %1."),
-						   	     Utils::get_filesystem_string( new_fs ) ) ,
+					   String::ucompose( 
+							/* TO TRANSLATORS: looks like
+							* Cannot format this file system to fat16.
+							*/
+							_( "Cannot format this file system to %1." ),
+							   Utils::get_filesystem_string( new_fs ) ) ,
 					   false,
 					   Gtk::MESSAGE_ERROR,
 					   Gtk::BUTTONS_OK,
 					   true );
 
 		if ( selected_partition .get_byte_length() < fs .MIN )
-			dialog .set_secondary_text( String::ucompose( 
+			dialog .set_secondary_text( String::ucompose(
+						/* TO TRANSLATORS: looks like
+						 * A fat16 file system requires a partition of at least 16.00 MiB.
+						 */
 						_( "A %1 file system requires a partition of at least %2."),
 						Utils::get_filesystem_string( new_fs ),
 						Utils::format_size( fs .MIN, 1 /* Byte */ ) ) );
 		else
-			dialog .set_secondary_text( String::ucompose( 
+			dialog .set_secondary_text( String::ucompose(
+						/* TO TRANSLATORS: looks like
+						 * A partition with a hfs file system has a maximum size of 2.00 GiB.
+						 */
 						_( "A partition with a %1 file system has a maximum size of %2."),
 						Utils::get_filesystem_string( new_fs ),
 						Utils::format_size( fs .MAX, 1 /* Byte */ ) ) );
@@ -1780,9 +1822,42 @@ void Win_GParted::thread_toggle_swap( bool * succes, Glib::ustring * error )
 
 	pulse = false ;
 }
-	
+
 void Win_GParted::toggle_swap_mount_state() 
-{	
+{
+	int operation_count = partition_in_operation_queue_count( selected_partition ) ;
+	if ( operation_count > 0 )
+	{
+		//Note that this situation will only occur when trying to swapon a partition.
+		//  This is because GParted does not permit queueing operations on partitions
+		//  that are currently active (i.e., swap enabled, or mounted).  Hence this
+		//  situation will not occur for the swapoff or unmount actions that this
+		//  method handles.
+
+		/*TO TRANSLATORS: Singular case looks like   1 operation is currently pending for partition /dev/sdd8. */
+		Glib::ustring tmp_msg =
+		    String::ucompose( ngettext( "%1 operation is currently pending for partition %2."
+		                              , "%1 operations are currently pending for partition %2."
+		                              , operation_count
+		                              )
+		                    , operation_count
+		                    , selected_partition .get_path()
+		                    ) ;
+		Gtk::MessageDialog dialog( *this
+		                         , tmp_msg
+		                         , false
+		                         , Gtk::MESSAGE_INFO
+		                         , Gtk::BUTTONS_OK
+		                         , true
+		                         ) ;
+		tmp_msg  = _( "The swapon action cannot be performed if an operation is pending for the partition." ) ;
+		tmp_msg += "\n" ;
+		tmp_msg += _( "Use the Edit menu to undo, clear, or apply operations before using swapon with this partition." ) ;
+		dialog .set_secondary_text( tmp_msg ) ;
+		dialog .run() ;
+		return ;
+	}
+
 	bool succes = false ;
 	Glib::ustring error ;
 
@@ -1837,12 +1912,39 @@ void Win_GParted::toggle_swap_mount_state()
 
 	menu_gparted_refresh_devices() ;
 }
-	
+
 void Win_GParted::activate_mount_partition( unsigned int index ) 
 {
+	int operation_count = partition_in_operation_queue_count( selected_partition ) ;
+	if ( operation_count > 0 )
+	{
+		/*TO TRANSLATORS: Plural case looks like   4 operations are currently pending for partition /dev/sdd8. */
+		Glib::ustring tmp_msg =
+		    String::ucompose( ngettext( "%1 operation is currently pending for partition %2."
+		                              , "%1 operations are currently pending for partition %2."
+		                              , operation_count
+		                              )
+		                    , operation_count
+		                    , selected_partition .get_path()
+		                    ) ;
+		Gtk::MessageDialog dialog( *this
+		                         , tmp_msg
+		                         , false
+		                         , Gtk::MESSAGE_INFO
+		                         , Gtk::BUTTONS_OK
+		                         , true
+		                         ) ;
+		tmp_msg  = _( "The mount action cannot be performed if an operation is pending for the partition." ) ;
+		tmp_msg += "\n" ;
+		tmp_msg += _( "Use the Edit menu to undo, clear, or apply operations before using mount with this partition." ) ;
+		dialog .set_secondary_text( tmp_msg ) ;
+		dialog .run() ;
+		return ;
+	}
+
 	bool succes = false ;
 	Glib::ustring error ;
-	
+
 	pulse = true ;
 
 	thread = Glib::Thread::create( sigc::bind<Glib::ustring, bool *, Glib::ustring *>( 
@@ -1877,6 +1979,39 @@ void Win_GParted::activate_mount_partition( unsigned int index )
 
 void Win_GParted::activate_disklabel()
 {
+	//If there are active mounted partitions on the device then warn
+	//  the user that all partitions must be unactive before creating
+	//  a new partition table
+	int active_count = active_partitions_on_device_count( devices[ current_device ] ) ;
+	if ( active_count > 0 )
+	{
+		Glib::ustring tmp_msg =
+		    String::ucompose( /*TO TRANSLATORS: Singular case looks like  1 partition is currently active on device /dev/sda. */
+		                      ngettext( "%1 partition is currently active on device %2."
+		                      /*TO TRANSLATORS: Plural case looks like    3 partitions are currently active on device /dev/sda. */
+		                              , "%1 partitions are currently active on device %2."
+		                              , active_count
+		                              )
+		                    , active_count
+		                    , devices[ current_device ] .get_path()
+		                    ) ;
+		Gtk::MessageDialog dialog( *this
+		                         , tmp_msg
+		                         , false
+		                         , Gtk::MESSAGE_INFO
+		                         , Gtk::BUTTONS_OK
+		                         , true
+		                         ) ;
+		tmp_msg  = _( "A new partition table cannot be created when there are active partitions." ) ;
+		tmp_msg += "  " ;
+		tmp_msg += _( "Active partitions are those that are in use, such as a mounted file system, or enabled swap space." ) ;
+		tmp_msg += "\n" ;
+		tmp_msg += _( "Use Partition menu options, such as unmount or swapoff, to deactivate all partitions on this device before creating a new partition table." ) ;
+		dialog .set_secondary_text( tmp_msg ) ;
+		dialog .run() ;
+		return ;
+	}
+
 	//If there are pending operations then warn the user that these
 	//  operations must either be applied or cleared before creating
 	//  a new partition table.
@@ -2002,7 +2137,7 @@ void Win_GParted::activate_undo()
 	if ( ! operations .size() )
 		close_operationslist() ;
 }
-	
+
 void Win_GParted::remove_operation( int index, bool remove_all ) 
 {
 	if ( remove_all )
@@ -2024,6 +2159,53 @@ void Win_GParted::remove_operation( int index, bool remove_all )
 	}
 }
 
+int Win_GParted::partition_in_operation_queue_count( const Partition & partition )
+{
+	int operation_count = 0 ;
+
+	for ( unsigned int t = 0 ; t < operations .size() ; t++ )
+	{
+		if ( partition .get_path() == operations[ t ] ->partition_original .get_path() )
+			operation_count++ ;
+	}
+
+	return operation_count ;
+}
+
+int  Win_GParted::active_partitions_on_device_count( const Device & device )
+{
+	int active_count = 0 ;
+
+	//Count the active partitions on the device
+	for ( unsigned int k=0; k < device .partitions .size(); k++ )
+	{
+		//FIXME:  Should also count other types of active partitions, such as LVM2 when we know how.
+
+		//Count the active primary partitions
+		if (   device .partitions[ k ] .busy
+		    && device .partitions[ k ] .type != TYPE_EXTENDED
+		    && device .partitions[ k ] .type != TYPE_UNALLOCATED
+		   )
+			active_count++ ;
+
+		//Count the active logical partitions
+		if (   device .partitions[ k ] .busy
+		    && device .partitions[ k ] .type == TYPE_EXTENDED
+		   )
+		{
+			for ( unsigned int j=0; j < device .partitions[ k ] .logicals .size(); j++ )
+			{
+				if (   device .partitions[ k ] .logicals [ j ] .busy
+				    && device .partitions[ k ] .logicals [ j ] .type != TYPE_UNALLOCATED
+				   )
+					active_count++ ;
+			}
+		}
+	}
+
+	return active_count ;
+}
+
 void Win_GParted::activate_apply()
 {
 	Gtk::MessageDialog dialog( *this,
