@@ -160,6 +160,14 @@ bool fat32::resize( const Partition & partition_new, OperationDetail & operation
 	return true ;
 }
 
+bool fat32::move( const Partition & partition_new
+                , const Partition & partition_old
+                , OperationDetail & operationdetail
+                )
+{
+	return true ;
+}
+
 bool fat32::copy( const Glib::ustring & src_part_path, 
 		  const Glib::ustring & dest_part_path,
 		  OperationDetail & operationdetail )
