@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,8 +37,11 @@ FS linux_swap::get_filesystem_support()
 	if ( ! Glib::find_program_in_path( "vol_id" ) .empty() )
 		fs .read_label = FS::EXTERNAL ;
 
-	fs .copy = GParted::FS::GPARTED ;
-	fs .move = GParted::FS::GPARTED ;
+	if ( ! Glib::find_program_in_path( "swaplabel" ) .empty() )
+		fs .write_label = FS::EXTERNAL ;
+
+	fs .copy = GParted::FS::EXTERNAL ;
+	fs .move = GParted::FS::EXTERNAL ;
 	
 	return fs ;
 }
@@ -65,7 +68,7 @@ void linux_swap::read_label( Partition & partition )
 
 bool linux_swap::write_label( const Partition & partition, OperationDetail & operationdetail )
 {
-	return true ;
+	return ! execute_command( "swaplabel -L \"" + partition .label + "\" " + partition .get_path(), operationdetail ) ;
 }
 
 bool linux_swap::create( const Partition & new_partition, OperationDetail & operationdetail )
@@ -90,10 +93,42 @@ bool linux_swap::resize( const Partition & partition_new, OperationDetail & oper
 	return exit_status ;
 }
 
+bool linux_swap::move( const Partition & partition_new
+                     , const Partition & partition_old
+                     , OperationDetail & operationdetail
+                     )
+{
+	//Since linux-swap does not contain data, do not actually move the partition
+	operationdetail .add_child(
+	    OperationDetail(
+	                     /* TO TRANSLATORS: looks like   Partition move action skipped because linux-swap file system does not contain data */
+	                     String::ucompose( _("Partition move action skipped because %1 file system does not contain data")
+	                                     , Utils::get_filesystem_string( FS_LINUX_SWAP )
+	                                     )
+	                   , STATUS_NONE
+	                   , FONT_ITALIC
+	                   )
+	                          ) ;
+
+	return true ;
+}
+
 bool linux_swap::copy( const Glib::ustring & src_part_path,
 		       const Glib::ustring & dest_part_path,
 		       OperationDetail & operationdetail )
 {
+	//Since linux-swap does not contain data, do not actually copy the partition
+	operationdetail .add_child(
+	    OperationDetail(
+	                     /* TO TRANSLATORS: looks like   Partition copy action skipped because linux-swap file system does not contain data */
+	                     String::ucompose( _("Partition copy action skipped because %1 file system does not contain data")
+	                                     , Utils::get_filesystem_string( FS_LINUX_SWAP )
+	                                     )
+	                   , STATUS_NONE
+	                   , FONT_ITALIC
+	                   )
+	                          ) ;
+
 	return true ;
 }
 
